# 🌀 bluer-sandbox

🌀 A sandbox for ideas and experiments.

## installation

```bash
pip install bluer-sandbox
```

## aliases

[@arvancloud](./bluer_sandbox/docs/aliases/arvancloud.md), 
[@docker](./bluer_sandbox/docs/aliases/docker.md), 
[@notebooks](./bluer_sandbox/docs/aliases/notebooks.md), 
[@offline_llm](./bluer_sandbox/docs/aliases/offline_llm.md), 
[@speedtest](./bluer_sandbox/docs/aliases/speedtest.md), 
[@tor](./bluer_sandbox/docs/aliases/tor.md),
[@village](./bluer_sandbox/docs/aliases/village.md).

|   |   |   |
| --- | --- | --- |
| [`ai4k`](./bluer_sandbox/docs/ai4k) [![image](https://github.com/kamangir/assets2/raw/main/ai4k/20250604_154200.jpg?raw=true)](./bluer_sandbox/docs/ai4k) ai for kids. | [`bluer village`](./bluer_sandbox/docs/aliases/village.md) [![image](https://github.com/kamangir/assets/raw/main/blue-plugin/marquee.png?raw=true)](./bluer_sandbox/docs/aliases/village.md) a bluer village. | [`arvancloud`](./bluer_sandbox/docs/arvancloud.md) [![image](https://github.com/kamangir/assets/raw/main/arvancloud/arvancloud.png?raw=true)](./bluer_sandbox/docs/arvancloud.md) tools to work with [arvancloud](https://arvancloud.ir/). |
| [`tor`](./bluer_sandbox/docs/tor.md) [![image](https://github.com/kamangir/assets/raw/main/tor/tor2.png?raw=true)](./bluer_sandbox/docs/tor.md) tools to work with [tor](https://www.torproject.org/). | [`offline LLM`](./bluer_sandbox/docs/offline_llm.md) [![image](https://user-images.githubusercontent.com/1991296/230134379-7181e485-c521-4d23-a0d6-f7b3b61ba524.png)](./bluer_sandbox/docs/offline_llm.md) using [llama.cpp](https://github.com/ggerganov/llama.cpp). |  |

---

> 🌀 [`blue-sandbox`](https://github.com/kamangir/blue-sandbox) for the [Global South](https://github.com/kamangir/bluer-south).

---


[![pylint](https://github.com/kamangir/bluer-sandbox/actions/workflows/pylint.yml/badge.svg)](https://github.com/kamangir/bluer-sandbox/actions/workflows/pylint.yml) [![pytest](https://github.com/kamangir/bluer-sandbox/actions/workflows/pytest.yml/badge.svg)](https://github.com/kamangir/bluer-sandbox/actions/workflows/pytest.yml) [![bashtest](https://github.com/kamangir/bluer-sandbox/actions/workflows/bashtest.yml/badge.svg)](https://github.com/kamangir/bluer-sandbox/actions/workflows/bashtest.yml) [![PyPI version](https://img.shields.io/pypi/v/bluer-sandbox.svg)](https://pypi.org/project/bluer-sandbox/) [![PyPI - Downloads](https://img.shields.io/pypi/dd/bluer-sandbox)](https://pypistats.org/packages/bluer-sandbox)

built by 🌀 [`bluer README`](https://github.com/kamangir/bluer-objects/tree/main/bluer_objects/README), based on 🌀 [`bluer_sandbox-5.516.1`](https://github.com/kamangir/bluer-sandbox).
